package com.jiuqi.monitor;

import java.util.Stack;

/* loaded from: com_jiuqi_monitor.jar:com/jiuqi/monitor/AbstractProgressMonitor.class */
public abstract class AbstractProgressMonitor implements IProgressMonitor {
    private volatile boolean canceled;
    private volatile double position;
    private Stack tasks = new Stack();
    private static final double POS_DELTA = 1.0E-4d;

    @Override // com.jiuqi.monitor.IProgressMonitor
    public abstract void prompt(String str);

    protected abstract void notify(double d);

    @Override // com.jiuqi.monitor.IProgressMonitor
    public void cancel() {
        this.canceled = true;
    }

    @Override // com.jiuqi.monitor.IProgressMonitor
    public void finishTask() {
        if (this.tasks.isEmpty()) {
            return;
        }
        this.tasks.pop();
        if (this.tasks.isEmpty()) {
            this.position = 1.0d;
            notify(this.position);
        }
    }

    @Override // com.jiuqi.monitor.IProgressMonitor
    public double getPosition() {
        return this.position;
    }

    @Override // com.jiuqi.monitor.IProgressMonitor
    public boolean isCanceled() {
        return this.canceled;
    }

    @Override // com.jiuqi.monitor.IProgressMonitor
    public void startTask(String taskName, int stepCount) {
        ProgressTask curTask = this.tasks.isEmpty() ? null : (ProgressTask) this.tasks.peek();
        this.tasks.push(new ProgressTask(curTask, taskName, stepCount));
    }

    @Override // com.jiuqi.monitor.IProgressMonitor
    public void startTask(String taskName, int[] steps) {
        ProgressTask curTask = this.tasks.isEmpty() ? null : (ProgressTask) this.tasks.peek();
        this.tasks.push(new ProgressTask(curTask, taskName, steps));
    }

    @Override // com.jiuqi.monitor.IProgressMonitor
    public void stepIn() {
        if (this.tasks.empty()) {
            return;
        }
        ProgressTask curTask = (ProgressTask) this.tasks.peek();
        curTask.stepIn();
        double pos = curTask.position();
        if (pos > this.position) {
            if (pos - this.position > POS_DELTA) {
                notify(pos);
            }
            this.position = pos;
        }
    }

    @Override // com.jiuqi.monitor.IProgressMonitor
    public String getCurrentTask() {
        if (this.tasks.isEmpty()) {
            return null;
        }
        return ((ProgressTask) this.tasks.peek()).name();
    }

    @Override // com.jiuqi.monitor.IProgressMonitor
    public int getCurrentLevel() {
        return this.tasks.size();
    }
}
